guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

05/05: gnu: lofreq: Set file timestamps to 1980s.


From: guix-commits
Subject: 05/05: gnu: lofreq: Set file timestamps to 1980s.
Date: Tue, 25 Apr 2023 10:30:21 -0400 (EDT)

rekado pushed a commit to branch master
in repository guix.

commit 3a37e3ecd8ae0bcc0e5d00393fa9365d611bcb71
Author: Ricardo Wurmus <rekado@elephly.net>
AuthorDate: Tue Apr 25 16:15:06 2023 +0200

    gnu: lofreq: Set file timestamps to 1980s.
    
    This keeps Python from complaining: "ZIP does not support timestamps before
    1980".
    
    * gnu/packages/bioinformatics.scm (lofreq)[arguments]: Add build phase
    'set-source-file-times-to-1980.
---
 gnu/packages/bioinformatics.scm | 12 +++++++++++-
 1 file changed, 11 insertions(+), 1 deletion(-)

diff --git a/gnu/packages/bioinformatics.scm b/gnu/packages/bioinformatics.scm
index 84e686c774..dfe82efe22 100644
--- a/gnu/packages/bioinformatics.scm
+++ b/gnu/packages/bioinformatics.scm
@@ -17761,7 +17761,17 @@ genomes known to contain a given k-mer.")
     (build-system gnu-build-system)
     (arguments
      '(#:test-target "bug-tests"
-       #:tests? #false)) ; test data are not included
+       #:tests? #false ;test data are not included
+       #:phases
+       (modify-phases %standard-phases
+         (add-after 'unpack 'set-source-file-times-to-1980
+           (lambda _
+             (let ((circa-1980 (* 10 366 24 60 60)))
+               (for-each (lambda (file)
+                           (let ((s (lstat file)))
+                             (unless (eq? (stat:type s) 'symlink)
+                               (utime file circa-1980 circa-1980))))
+                         (find-files "." #:directories? #t))))))))
     (inputs
      (list htslib python-wrapper zlib))
     (native-inputs



reply via email to

[Prev in Thread] Current Thread [Next in Thread]